#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http2
version:              5.1.4
visibility:           public
id:                   http2-5.1.4-9xknwToXy8TKqakz2e28TO
key:                  http2-5.1.4-9xknwToXy8TKqakz2e28TO
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http2
synopsis:             HTTP/2 library
description:
    HTTP/2 library including frames, priority queues, HPACK, client and server.

category:             Network
abi:                  a300fefa2d3d5ca72e0e17519d365142
exposed:              True
exposed-modules:
    Network.HPACK Network.HPACK.Internal Network.HPACK.Table
    Network.HPACK.Token Network.HTTP2.Client
    Network.HTTP2.Client.Internal Network.HTTP2.Frame
    Network.HTTP2.Internal Network.HTTP2.Server
    Network.HTTP2.Server.Internal

hidden-modules:
    Imports Network.HPACK.Builder Network.HTTP2.Client.Types
    Network.HTTP2.Client.Run Network.HPACK.HeaderBlock
    Network.HPACK.HeaderBlock.Decode Network.HPACK.HeaderBlock.Encode
    Network.HPACK.HeaderBlock.Integer Network.HPACK.Huffman
    Network.HPACK.Huffman.Bit Network.HPACK.Huffman.ByteString
    Network.HPACK.Huffman.Decode Network.HPACK.Huffman.Encode
    Network.HPACK.Huffman.Params Network.HPACK.Huffman.Table
    Network.HPACK.Huffman.Tree Network.HPACK.Table.Dynamic
    Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
    Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.H2
    Network.HTTP2.H2.Config Network.HTTP2.H2.Context
    Network.HTTP2.H2.EncodeFrame Network.HTTP2.H2.File
    Network.HTTP2.H2.HPACK Network.HTTP2.H2.Manager
    Network.HTTP2.H2.Queue Network.HTTP2.H2.ReadN
    Network.HTTP2.H2.Receiver Network.HTTP2.H2.Sender
    Network.HTTP2.H2.Settings Network.HTTP2.H2.Status
    Network.HTTP2.H2.Stream Network.HTTP2.H2.StreamTable
    Network.HTTP2.H2.Types Network.HTTP2.H2.Window
    Network.HTTP2.Frame.Decode Network.HTTP2.Frame.Encode
    Network.HTTP2.Frame.Types Network.HTTP2.Server.Run
    Network.HTTP2.Server.Types Network.HTTP2.Server.Worker

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http2-5.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http2-5.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http2-5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http2
hs-libraries:         HShttp2-5.1.4-9xknwToXy8TKqakz2e28TO
depends:
    array-0.5.6.0 async-2.2.6-13RsU0DgnQr2Fu0srq1209 base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    containers-0.6.7 http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    network-3.1.4.0-6Vir8NKcwTtGDZOkjzNXEQ
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
    network-control-0.1.3-9i56jiIyVwi44NYyr06hYO stm-2.5.1.0
    time-manager-0.0.1-H39O0kuXxKu1e7a99KiHMp
    unix-time-0.4.17-FcJXVVKL6zA6bExEptRQf3
    unliftio-0.2.25.1-8Cmk1kbG8582HEPFTOgSAB
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html:         /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

